"""
This library will make the DOCX
creation process very easy.

# Install with 'pip install python-docx'

Some examples here:
- https://python-docx.readthedocs.io/en/latest/
- https://python-docx.readthedocs.io/en/latest/user/quickstart.html
"""
from dal_docx_creator.example import DocxExample

DocxExample.test_one()